@@ -56,7 +56,7 @@ class CardsManager:
                 'description': template['description'].format(*entry)
             }
             cards.append(card)
-            headers.append(values[0])
+            headers.append(str(entry[0]) + '_sectors')
         self.deck_storm = cards
         self.headers_deck_storm = headers
 
@@ -74,7 +74,7 @@ class CardsManager:
                 'description': template['description'].format(*entry)
             }
             cards.append(card)
-            headers.append(values[0])
+            headers.append('traitor_' + entry[0])
         self.deck_traitor = cards
         self.headers_deck_traitor = headers
 
@@ -117,13 +117,16 @@ class ConfigManager:
     def getRegions(self):
         return self.game_config['generated']['regions']
 
-    def getRegionsChoices(self, sort=False, reverse=False):
+    def getRegionsChoices(self, sort=False, reverse=False, swap=False):
         regions = self.getRegions()
         choices = []
         for region in regions:
-            value = region.replace('R', 'region ')
+            region_value = region.replace('R', 'region ')
+            name, value = region, region_value
+            if swap:
+                value, name = region, region_value
             choices.append({
-                'name': region,
+                'name': name,
                 'value': value
             })
         if sort:
@@ -133,15 +136,18 @@ class ConfigManager:
     def getLocations(self):
         return self.game_config['generated']['locations']
 
-    def getLocationsChoices(self, sort=False, reverse=False):
+    def getLocationsChoices(self, sort=False, reverse=False, swap=False):
         locations = self.getLocations()
         choices = []
         for location in locations:
             if location == 'arrakis':
                 continue
-            value = location.replace('_', ' ').title()
+            location_name = location.replace('_', ' ').title()
+            name, value = location, location_name
+            if swap:
+                value, name = location, location_name
             choices.append({
-                'name': location,
+                'name': name,
                 'value': value
             })
         if sort:
@@ -165,6 +171,26 @@ class ConfigManager:
             choices = sorted(choices, key=lambda choice: len(choice['name']), reverse=reverse)
         return choices
 
+    def getDeckChoices(self):
+        return [
+            {
+                'name': 'Treachery deck',
+                'value': 'treachery'
+            },
+            {
+                'name': 'Spice deck',
+                'value': 'spice'
+            },
+            {
+                'name': 'Storm deck',
+                'value': 'storm'
+            },
+            {
+                'name': 'Traitor deck',
+                'value': 'traitor'
+            }
+        ]
+
 
     def isAreaPoint(self, area_name):
         return area_name in self.game_config['types']['areas']['point']
@@ -639,30 +665,33 @@ class OriginatorTruthsayer(OriginatorJSON):
         cmd = '/{0} {1}'.format('storm', region)
         self.appendCMD(cmd)
 
-    def peek(self, player, deck):
+    def peek(self, faction, deck):
         if deck not in self._object_state['hidden']['decks'].keys():
             raise ValueError('Invalid deck name')
-        faction = self._object_state['meta']['factions'][player]
         cmd = '/{0} {1} {2}'.format('peek', faction, deck)
         self.appendCMD(cmd)
-        card_id = self._object_state['meta']['decks'][deck][0]
+        card_id = self._object_state['hidden']['decks'][deck][0]
         card = self.cards_manager.card_objects[card_id]
-        return card
+        game_id = self._object_state['meta']['texts']['game_id']
+        return game_id, card
 
-    def draw(self, player, deck):
+    def draw(self, faction, deck):
+        for name in self._object_state['hidden']['decks'].keys():
+            print(name)
         if deck not in self._object_state['hidden']['decks'].keys():
             raise ValueError('Invalid deck name')
-        faction = self._object_state['meta']['factions'][player]
         cmd = '/{0} {1} {2}'.format('draw', faction, deck)
         self.appendCMD(cmd)
         card_id = self._object_state['hidden']['decks'][deck].pop()
         self._object_state['hidden']['cards'][faction].append(card_id)
         card = self.cards_manager.card_objects[card_id]
-        return card
+        game_id = self._object_state['meta']['texts']['game_id']
+        return game_id, card
 
-    def hand(self, player):
-        faction = self._object_state['meta']['factions'][player]
+    def hand(self, faction):
         return {
+            'game_id': self._object_state['meta']['texts']['game_id'],
+            'faction_name': self.processor.game_config['faction_names'][faction],
             'cards': self._object_state['hidden']['cards'][faction],
             'spice': self._object_state['hidden']['spice'][faction],
             'reserves': self._object_state['hidden']['reserves'][faction]
